@@ -1,7 +1,7 @@
 import datetime
 import numbers
 import re
-from py.test import mark
+from py.test import mark, raises
 
 from wand.version import (MAGICK_VERSION, MAGICK_VERSION_INFO,
                           MAGICK_VERSION_NUMBER, MAGICK_RELEASE_DATE,
@@ -11,7 +11,7 @@ from wand.version import (MAGICK_VERSION, MAGICK_VERSION_INFO,
 
 def test_version():
     """Test version strings."""
-    match = re.match('^ImageMagick\s+\d+\.\d+\.\d+(?:-\d+)?', MAGICK_VERSION)
+    match = re.match(r'^ImageMagick\s+\d+\.\d+\.\d+(?:-\d+)?', MAGICK_VERSION)
     assert match
     assert isinstance(MAGICK_VERSION_INFO, tuple)
     assert (len(MAGICK_VERSION_INFO) ==
@@ -19,8 +19,9 @@ def test_version():
     assert all(isinstance(v, int) for v in MAGICK_VERSION_INFO)
     assert isinstance(MAGICK_VERSION_NUMBER, numbers.Integral)
     assert isinstance(MAGICK_RELEASE_DATE, datetime.date)
-    assert (MAGICK_RELEASE_DATE_STRING ==
-            MAGICK_RELEASE_DATE.strftime('%Y-%m-%d'))
+    date_strings = (MAGICK_RELEASE_DATE.strftime('%Y-%m-%d'),
+                    MAGICK_RELEASE_DATE.strftime('%Y%m%d'))
+    assert MAGICK_RELEASE_DATE_STRING in date_strings
 
 
 def test_quantum_depth():
@@ -30,6 +31,8 @@ def test_quantum_depth():
 
 def test_configure_options():
     assert 'RELEASE_DATE' in configure_options('RELEASE_DATE')
+    with raises(TypeError):
+        configure_options(0xDEADBEEF)
 
 
 def test_fonts():
@@ -38,8 +41,12 @@ def test_fonts():
     first_font = font_list[0]
     first_font_part = first_font[1:-1]
     assert first_font in fonts('*{0}*'.format(first_font_part))
+    with raises(TypeError):
+        fonts(0xDEADBEEF)
 
 
 def test_formats():
     xc = 'XC'
     assert formats(xc) == [xc]
+    with raises(TypeError):
+        formats(0xDEADBEEF)
